@@ -1,5 +1,7 @@
 """A Redis Database Cache Class"""
+import os
 import json
+
 import redis
 import logging
 from datetime import datetime, date
@@ -26,23 +28,38 @@ class RedisCache:
     """
 
     # Setup logger (class attribute)
-    log = logging.getLogger(__name__)
+    log = logging.getLogger("sageworks")
 
-    # FIXME: Get these from SageWorks configuration
-    host = "localhost"
-    port = 6379
-    password = None
+    # Try to read Redis configuration from environment variables
+    host = os.environ.get("REDIS_HOST", "localhost")
+    port = os.environ.get("REDIS_PORT", "6379")
+    password = os.environ.get("REDIS_PASSWORD", None)
 
     # Open the Redis connection (class object)
     log.info(f"Opening Redis connection to: {host}:{port}...")
-    redis_db = redis.Redis(host, port=port, password=password, charset="utf-8", decode_responses=True, db=0)
+    redis_db = None
     try:
-        redis_db.ping()
+        # Create a temporary connection to test the connection
+        _redis_db = redis.Redis(host, port=port, password=password, socket_timeout=1)
+        _redis_db.ping()
+
+        # Now create the actual connection
+        redis_db = redis.Redis(
+            host,
+            port=port,
+            password=password,
+            charset="utf-8",
+            decode_responses=True,
+            db=0,
+        )
         log.info(f"Redis connection success: {host}:{port}...")
     except (redis.exceptions.ConnectionError, redis.exceptions.TimeoutError):
         msg = f"Could not connect to Redis Database: {host}:{port}..."
-        log.critical(msg)
-        raise RuntimeError(msg)
+        log.warning(msg)
+
+    @classmethod
+    def check(cls):
+        return cls.redis_db is not None
 
     def __init__(self, expire=None, prefix="", postfix=""):  # No expiration, standard 0 db, no postfix on keys
         """RedisCache Initialization"""
@@ -133,6 +150,9 @@ if __name__ == "__main__":
 
     # Create a RedisCache
     my_redis_cache = RedisCache(prefix="test")
+    if not my_redis_cache.check():
+        print("Redis not available, exiting...")
+        exit(1)
 
     # Delete anything in the test database
     my_redis_cache.clear()
