@@ -15,11 +15,13 @@ logging_setup()
 class View(ABC):
     def __init__(self):
         """View: View in the database sense: Pulls from the AWS Service Broker and does slice and dice"""
-        self.log = logging.getLogger(__name__)
+        self.log = logging.getLogger("sageworks")
 
         # Grab an AWS Metadata Broker object for pulling AWS Service information
         self.aws_broker = AWSServiceBroker()
-        self.boto_session = AWSAccountClamp().boto_session()
+        self.aws_account_clamp = AWSAccountClamp()
+        self.boto_session = self.aws_account_clamp.boto_session()
+        self.sm_session = self.aws_account_clamp.sagemaker_session()
 
     @abstractmethod
     def check(self) -> bool:
