@@ -6,12 +6,13 @@ from sageworks.artifacts.data_sources.athena_source import AthenaSource
 
 def test():
     """Tests for the DataSource/AthenaSource functionality"""
+    from pprint import pprint
 
     # Retrieve our test Data Source
     my_data = AthenaSource("test_data")
 
     # Verify that the Athena Data Source exists
-    assert my_data.check()
+    assert my_data.exists()
 
     # What's my SageWorks UUID
     print(f"UUID: {my_data.uuid}")
@@ -29,10 +30,13 @@ def test():
     print(f"Created: {my_data.created()}")
     print(f"Modified: {my_data.modified()}")
 
-    # Get Metadata and tags associated with this Artifact
-    print(f"Meta: {my_data.sageworks_meta()}")
+    # Get Tags associated with this Artifact
     print(f"Tags: {my_data.sageworks_tags()}")
 
+    # Get ALL the AWS Metadata associated with this Artifact
+    print("\n\nALL Meta")
+    pprint(my_data.aws_meta())
+
     # Now delete the AWS artifacts associated with this DataSource
     # print('Deleting SageWorks Data Source...')
     # my_data.delete()
