@@ -1,9 +1,11 @@
 """Tests for the Data to Data (light) Transforms"""
+import pytest
 
 # Local imports
 from sageworks.transforms.data_to_data.light.data_to_data_light import DataToDataLight
 
 
+@pytest.mark.slow
 def test():
     """Tests for the Data to Data (light) Transforms"""
 
@@ -12,7 +14,7 @@ def test():
     output_uuid = "abalone_data_copy"
     data_to_data = DataToDataLight(input_uuid, output_uuid)
     data_to_data.set_output_tags(["abalone", "public"])
-    data_to_data.transform(delete_existing=True)
+    data_to_data.transform()
 
 
 if __name__ == "__main__":
