@@ -1,4 +1,5 @@
 """Tests for the Data to Data (light) Transforms"""
+import pytest
 
 # Local imports
 from sageworks.transforms.data_to_features.light.data_to_features_light import (
@@ -7,6 +8,7 @@ from sageworks.transforms.data_to_features.light.data_to_features_light import (
 
 
 # Simple test of the DataToFeaturesLight functionality
+@pytest.mark.slow
 def test():
     """Tests for the Data to Features (light) Transforms"""
 
@@ -15,7 +17,7 @@ def test():
     output_uuid = "test_feature_set"
     data_to_features = DataToFeaturesLight(input_uuid, output_uuid)
     data_to_features.set_output_tags(["test", "small"])
-    data_to_features.transform(id_column="id", event_time_column="date", delete_existing=True)
+    data_to_features.transform(id_column="id", event_time_column="date")
 
 
 if __name__ == "__main__":
